# Index

D | E | H | M | N | S | T

## D

default_auto_field (maillib.apps.MaillibConfig attribute)

## E

emailapp module emailapp.asgi module emailapp.settings module | emailapp.urls module emailapp.wsgi module

## H

home() (in module maillib.views)

## M

maillib module maillib.admin module maillib.apps module maillib.migrations module maillib.models module maillib.tests module maillib.tests.test_urls module maillib.tests.test_views module maillib.urls module | maillib.views module MaillibConfig (class in maillib.apps) module emailapp emailapp.asgi emailapp.settings emailapp.urls emailapp.wsgi maillib maillib.admin maillib.apps maillib.migrations maillib.models maillib.tests maillib.tests.test_urls maillib.tests.test_views maillib.urls maillib.views

## N

name (maillib.apps.MaillibConfig attribute)

## S

setUp() (maillib.tests.test_views.TestViews method)

## T

test_email_validate() (maillib.tests.test_views.TestViews method) test_home_url_resolved() (maillib.tests.test_urls.TestUrls method) test_send_email() (maillib.tests.test_views.TestViews method) | test_should_show_home_page() (maillib.tests.test_views.TestViews method) test_valid_email() (maillib.tests.test_views.TestViews method) TestUrls (class in maillib.tests.test_urls) TestViews (class in maillib.tests.test_views)